@@ -9,18 +9,18 @@
 """
 import unittest
 
-from .test_banner import TestBanner
+from .test_banner import TestBanner, TestGetHtml
 from .test_cms import TestCMS
-from .test_view_depends import TestViewDepends
 from .test_menu_for import TestMenuFor
 
 
+
 def suite():
     test_suite = unittest.TestSuite()
     test_suite.addTests([
         unittest.TestLoader().loadTestsFromTestCase(TestBanner),
+        unittest.TestLoader().loadTestsFromTestCase(TestGetHtml),
         unittest.TestLoader().loadTestsFromTestCase(TestCMS),
         unittest.TestLoader().loadTestsFromTestCase(TestMenuFor),
-        unittest.TestLoader().loadTestsFromTestCase(TestViewDepends)
     ])
     return test_suite
